@@ -32,6 +32,8 @@
 #' @param text_rotation Integer. Rotation of text in degrees. Must be an integer between -90 and
 #' 90.
 #' @param indent Integer. The number of indent positions, must be an integer between 0 and 250.
+#' @param col_width Numeric. The column width.
+#' @param ... Dots. For future expansions. Must be empty.
 #'
 #' @return a `xlr_format` S3 class.
 #'
@@ -95,13 +97,15 @@ xlr_format <- function(font_size = 11,
                        valign = "top",
                        wrap_text = FALSE,
                        text_rotation = 0L,
-                       indent = 0L){
+                       indent = 0L,
+                       col_width = 10.00,
+                       ...){
 
   # first we convert the numerics to the right type
   font_size = vec_cast(font_size,double())
   text_rotation = vec_cast(text_rotation,integer())
   indent = vec_cast(indent,integer())
-
+  col_width = vec_cast(col_width, double())
   # first we do a bunch of coersions to null if something
   # is null
 
@@ -119,7 +123,9 @@ xlr_format <- function(font_size = 11,
     valign,
     wrap_text,
     text_rotation,
-    indent
+    indent,
+    col_width,
+    ...
   )
 
   # construct a new object
@@ -136,7 +142,8 @@ xlr_format <- function(font_size = 11,
     valign = valign,
     wrap_text = wrap_text,
     text_rotation = text_rotation,
-    indent = indent
+    indent = indent,
+    col_width = col_width
   )
 }
 
@@ -154,7 +161,8 @@ xlr_format_numeric <-function(font_size = 11,
                               valign = "bottom",
                               wrap_text = FALSE,
                               text_rotation = 0L,
-                              indent = 0L){
+                              indent = 0L,
+                              col_width = 10.0){
 
   xlr_format(
     font_size = font_size,
@@ -169,7 +177,8 @@ xlr_format_numeric <-function(font_size = 11,
     valign = valign,
     wrap_text = wrap_text,
     text_rotation = text_rotation,
-    indent = indent
+    indent = indent,
+    col_width = col_width
   )
 }
 
@@ -201,6 +210,8 @@ print.xlr_format <- function(x,...){
                "Indent: {.val {attr(x,which='indent')}}, ",
                "Rotation: {.val {attr(x,which='text_rotation')}}, ",
                "Wrap text: {.val {attr(x,which='wrap_text')}}"))
+    cli_text("-- Column Width:")
+    cli_text("Col width: {.val {attr(x,which='col_width')}}")
   },
   strip_newline = TRUE)
   cat(paste(x,collapse="\n"))
@@ -239,6 +250,8 @@ print.xlr_format <- function(x,...){
                     attr(e2,which="text_rotation")),
     custom_equality(attr(e1,which="indent"),
                     attr(e2,which="indent")),
+    custom_equality(attr(e1,which="col_width"),
+                    attr(e2,which="col_width")),
     na.rm = TRUE
   )
 }
@@ -262,6 +275,7 @@ new_xlr_format <- function(font_size = 11,
                             wrap_text = FALSE,
                             text_rotation = 0L,
                             indent = 0L,
+                            col_width = 10.0,
                             call = caller_env()){
 
 
@@ -284,7 +298,8 @@ new_xlr_format <- function(font_size = 11,
     valign = valign,
     wrap_text = wrap_text,
     text_rotation = text_rotation,
-    indent = indent
+    indent = indent,
+    col_width = col_width
   )
 }
 
@@ -303,6 +318,8 @@ validate_xlr_format <- function(
     wrap_text,
     text_rotation,
     indent,
+    col_width,
+    ...,
     call = caller_env()){
 
   type_abort(font_size,is_scalar_double,1.1,call=call)
@@ -447,7 +464,18 @@ validate_xlr_format <- function(
               call = call)
   }
 
+  # the column width must be between 0 and 255
+  type_abort(col_width, is_scalar_double,10.0,call = call)
+  if (col_width < 0 || col_width > 255){
+    cli_abort(c("i" = "In argument: {.code col_width}.",
+                "!" = "{.code col_width} must be between 0 and 255."),
+              call = call)
+  }
 
+  check_dots_empty(env = caller_env(1),
+                   call = call)
+
+  # check that the d
   return(TRUE)
 }
 
